==> jbpm-distro-4.1.jar: jbpm-4.1/src/org/jbpm/jpdl/internal/activity/SubProcessInParameterImpl.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.jpdl.internal.activity;

import org.jbpm.pvm.internal.env.EnvironmentDefaults;
import org.jbpm.pvm.internal.model.ExecutionImpl;
import org.jbpm.pvm.internal.script.ScriptManager;


/**
 * @author Tom Baeyens
 */
public class SubProcessInParameterImpl extends SubProcessParameterImpl {

  private static final long serialVersionUID = 1L;
  
  public void produce(ExecutionImpl superExecution, ExecutionImpl subProcessInstance) {
    Object value = null;
    if (variableName!=null) {
      value = superExecution.getVariable(variableName);
    } else {
      ScriptManager scriptManager = EnvironmentDefaults.getScriptManager();
      value = scriptManager.evaluateExpression(expression, language);
    }
    
    subProcessInstance.setVariable(subVariableName, value);
  }
}

==> jbpm-distro-4.2.jar: jbpm-4.2/src/org/jbpm/jpdl/internal/activity/SubProcessInParameterImpl.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.jpdl.internal.activity;

import org.jbpm.pvm.internal.model.ExecutionImpl;
import org.jbpm.pvm.internal.script.ScriptManager;


/**
 * @author Tom Baeyens
 */
public class SubProcessInParameterImpl extends SubProcessParameterImpl {

  private static final long serialVersionUID = 1L;
  
  public void produce(ExecutionImpl superExecution, ExecutionImpl subProcessInstance) {
    Object value = null;
    if (variableName!=null) {
      value = superExecution.getVariable(variableName);
    } else {
      ScriptManager scriptManager = ScriptManager.getScriptManager();
      value = scriptManager.evaluateExpression(expression, language);
    }
    
    subProcessInstance.setVariable(subVariableName, value);
  }
}
